@@ -501,9 +501,9 @@ ne_sock_connect_ssl (ne_socket *sock, ne_ssl_context *ctx,
 
 /* ************************************************************************** */
 
-#ifdef NEON_SSL
+#ifdef NE_HAVE_SSL
 int
-ne_negotiate_ssl (ne_request *req)
+ne__negotiate_ssl (ne_request *req)
 {
 	GnomeVFSSSL *ssl;
 	GnomeVFSCancellation *cancellation;
@@ -668,3 +668,7 @@ ne_ssl_certificate *ne_ssl_cert_import(const char *data)
 
 void ne_ssl_set_clicert(ne_session *sess, const ne_ssl_client_cert *cc) 
 {}
+
+void ne_ssl_context_trustcert(ne_ssl_context *ctx, const ne_ssl_certificate *cert)
+{
+}
